@@ -3,16 +3,19 @@
 # $1 - Version
 # $2 - Build version
 # $3 - Go source Dir. If not set then relative to the script dir
+# $4 - package suffix: empty or wx30
 
 set -e
 
-source $(dirname $0)/../set-ver-prms.sh "$1" "$2"
+DIR=$(dirname $0)
+source $DIR/../set-ver-prms.sh "$1" "$2"
 
 if [[ -n "$3" ]]; then
 	SRC_DIR=$3
 else
 	SRC_DIR=$(readlink -f $(dirname $0)/../..)
 fi
+PACKAGE_SUFFIX=$4
 
 PARALLEL_PRMS="-j$(nproc)"
 
@@ -38,7 +41,12 @@ GO_ARM_PRMS="-DCMAKE_SYSTEM_NAME=Linux \
   -DCPACK_DEBIAN_PACKAGE_ARCHITECTURE=arm64 \
   -DCPACK_RPM_PACKAGE_ARCHITECTURE=aarch64 \
   -DIMPORT_EXECUTABLES=../build-tools/ImportExecutables.cmake"
-GO_PRMS="-DCMAKE_BUILD_TYPE=Release $CMAKE_VERSION_PRMS"
+
+GO_PRMS="-DCMAKE_BUILD_TYPE=Release \
+  $CMAKE_VERSION_PRMS \
+  -DCMAKE_PACKAGE_SUFFIX=$PACKAGE_SUFFIX \
+  $($DIR/../for-linux/cmake-prm-yaml-cpp.bash arm64)"
+
 echo "cmake -G \"Unix Makefiles\" $GO_PRMS . $SRC_DIR"
 cmake -G "Unix Makefiles" $GO_PRMS $GO_ARM_PRMS . $SRC_DIR
 make -k $PARALLEL_PRMS VERBOSE=1 package
