@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -138,7 +138,10 @@ const wxString GOOrgan::GetOrganHash() const {
     hash.Update(m_ODF);
   } else {
     wxFileName odf(m_ODF);
-    odf.Normalize(wxPATH_NORM_ALL | wxPATH_NORM_CASE);
+
+    odf.Normalize(
+      wxPATH_NORM_DOTS | wxPATH_NORM_TILDE | wxPATH_NORM_CASE
+      | wxPATH_NORM_ABSOLUTE | wxPATH_NORM_LONG | wxPATH_NORM_SHORTCUT);
     wxString filename = odf.GetFullPath();
 
     hash.Update(filename);
