@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -60,7 +60,7 @@ const struct IniFileEnumEntry GOMidiReceiverBase::m_MidiTypes[] = {
 };
 
 void GOMidiReceiverBase::Load(
-  GOConfigReader &cfg, wxString group, GOMidiMap &map) {
+  GOConfigReader &cfg, const wxString &group, GOMidiMap &map) {
   m_events.resize(0);
 
   int event_cnt = cfg.ReadInteger(
@@ -903,8 +903,4 @@ GOMidiMatchType GOMidiReceiverBase::Match(
   return MIDI_MATCH_NONE;
 }
 
-void GOMidiReceiverBase::Assign(const GOMidiReceiverEventPatternList &data) {
-  *(GOMidiReceiverEventPatternList *)this = data;
-}
-
 void GOMidiReceiverBase::PreparePlayback() { m_Internal.resize(0); }
