@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -9,6 +9,7 @@
 #define GOMIDIRECEIVERBASE_H
 
 #include "GOMidiReceiverEventPatternList.h"
+#include "GOTime.h"
 
 class GOConfigReader;
 class GOConfigWriter;
@@ -41,7 +42,7 @@ protected:
 public:
   GOMidiReceiverBase(GOMidiReceiverType type);
 
-  virtual void Load(GOConfigReader &cfg, wxString group, GOMidiMap &map);
+  virtual void Load(GOConfigReader &cfg, const wxString &group, GOMidiMap &map);
   void Save(GOConfigWriter &cfg, wxString group, GOMidiMap &map);
   void PreparePlayback();
 
@@ -62,8 +63,6 @@ public:
   unsigned KeyLimit(GOMidiReceiverMessageType type);
   unsigned LowerValueLimit(GOMidiReceiverMessageType type);
   unsigned UpperValueLimit(GOMidiReceiverMessageType type);
-
-  virtual void Assign(const GOMidiReceiverEventPatternList &data);
 };
 
 #endif
