@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -8,10 +8,8 @@
 #ifndef GOMIDIRECEIVEREVENTPATTERNLIST_H
 #define GOMIDIRECEIVEREVENTPATTERNLIST_H
 
-#include <vector>
-
+#include "GOMidiEventPatternList.h"
 #include "GOMidiReceiverEventPattern.h"
-#include "GOTime.h"
 
 typedef enum {
   MIDI_RECV_DRAWSTOP,
@@ -30,21 +28,7 @@ typedef enum {
   MIDI_MATCH_RESET,
 } GOMidiMatchType;
 
-class GOMidiReceiverEventPatternList {
-protected:
-  GOMidiReceiverType m_type;
-  std::vector<GOMidiReceiverEventPattern> m_events;
-
-public:
-  GOMidiReceiverEventPatternList(GOMidiReceiverType type);
-  virtual ~GOMidiReceiverEventPatternList();
-
-  GOMidiReceiverType GetType() const;
-
-  unsigned GetEventCount() const;
-  GOMidiReceiverEventPattern &GetEvent(unsigned index);
-  unsigned AddNewEvent();
-  void DeleteEvent(unsigned index);
-};
+using GOMidiReceiverEventPatternList
+  = GOMidiEventPatternList<GOMidiReceiverType, GOMidiReceiverEventPattern>;
 
 #endif
