@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -13,10 +13,11 @@
 #include "document-base/GODocumentBase.h"
 #include "midi/GOMidiCallback.h"
 #include "midi/GOMidiListener.h"
+#include "midi/dialog-creator/GOMidiDialogCreator.h"
 #include "threading/GOMutex.h"
 
 class GOOrganController;
-class GOKeyReceiver;
+class GOMidiShortcutReceiver;
 class GOMidiEvent;
 class GOMidiReceiverBase;
 class GOMidiSender;
@@ -25,7 +26,9 @@ class GOProgressDialog;
 class GOResizable;
 class GOSound;
 
-class GODocument : public GODocumentBase, protected GOMidiCallback {
+class GODocument : public GODocumentBase,
+                   protected GOMidiCallback,
+                   public GOMidiDialogCreator {
 private:
   GOResizable *p_MainWindow;
   GOSound &m_sound;
@@ -45,28 +48,26 @@ public:
   GODocument(GOResizable *pMainWindow, GOSound *sound);
   ~GODocument();
 
+  GOOrganController *GetOrganController() const { return m_OrganController; }
   bool IsModified() const;
 
   void ShowPanel(unsigned id);
   void ShowOrganDialog();
-  void ShowMIDIEventDialog(
-    void *element,
-    wxString title,
-    GOMidiReceiverBase *event,
-    GOMidiSender *sender,
-    GOKeyReceiver *key,
-    GOMidiSender *division = NULL);
   void ShowMidiList();
 
-  bool Load(GOProgressDialog *dlg, const GOOrgan &organ);
   bool Save();
   bool Export(const wxString &cmb);
-  bool Import(GOProgressDialog *dlg, const GOOrgan &organ, const wxString &cmb);
-  bool ImportCombination(const wxString &cmb);
-  bool Revert(GOProgressDialog *dlg);
+  bool LoadOrgan(
+    GOProgressDialog *dlg, const GOOrgan &organ, const wxString &cmb);
   bool UpdateCache(GOProgressDialog *dlg, bool compress);
 
-  GOOrganController *GetOrganController() const { return m_OrganController; }
+  void ShowMIDIEventDialog(
+    void *element,
+    const wxString &title,
+    GOMidiReceiverBase *event,
+    GOMidiSender *sender,
+    GOMidiShortcutReceiver *key,
+    GOMidiSender *division = nullptr) override;
 };
 
 #endif
