@@ -1,22 +1,8 @@
 /*
- * GrandOrgue - a free pipe organ simulator
- *
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * License GPL-2.0 or later
+ * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
 
 #ifndef GOFRAME_H
@@ -30,6 +16,7 @@
 #include "help/GOHelpRequestor.h"
 #include "midi/GOMidiCallback.h"
 #include "midi/GOMidiListener.h"
+#include "modification/GOModificationListener.h"
 #include "threading/GOMutex.h"
 
 #include "GOEvent.h"
@@ -42,6 +29,7 @@ class GODocument;
 class GOMidiEvent;
 class GOOrgan;
 class GOOrganController;
+class GOProgressDialog;
 class GOSound;
 class wxChoice;
 class wxHtmlHelpController;
@@ -52,7 +40,8 @@ class wxToolBarToolBase;
 class GOFrame : public wxFrame,
                 private GOHelpRequestor,
                 public GOResizable,
-                protected GOMidiCallback {
+                protected GOMidiCallback,
+                private GOModificationListener {
 private:
   GOApp &m_App;
   GOMutex m_mutex;
@@ -87,7 +76,8 @@ private:
   int m_AfterSettingsEventId;
   GOOrgan *p_AfterSettingsEventOrgan;
 
-  void UpdateReleaseLength();
+  // Updates ReleseLength in the model, in the config, and in the control
+  void UpdateReleaseLength(unsigned releaseLength);
   void UpdatePanelMenu();
   void UpdateFavoritesMenu();
   void UpdateRecentMenu();
@@ -99,8 +89,15 @@ private:
   // Returns the current open organ controller or nullptr
   GOOrganController *GetOrganController() const;
 
-  void OnMeters(wxCommandEvent &event);
+  void AttachDetachOrganController(bool isToAttach);
 
+  // Processes the organ model modification event:
+  // updates some controls according the organ model changes
+  void OnIsModifiedChanged(bool modified) override;
+
+  bool LoadOrgan(const GOOrgan &organ, const wxString &cmb = wxEmptyString);
+
+  void OnMeters(wxCommandEvent &event);
   void OnLoadFile(wxCommandEvent &event);
   void OnLoad(wxCommandEvent &event);
   void OnLoadFavorite(wxCommandEvent &event);
@@ -110,8 +107,9 @@ private:
   void OnSave(wxCommandEvent &event);
   void OnMenuClose(wxCommandEvent &event);
   void OnExit(wxCommandEvent &event);
-  void OnImportSettings(wxCommandEvent &event);
   void OnImportCombinations(wxCommandEvent &event);
+  void OnExportCombinations(wxCommandEvent &event);
+  void OnImportSettings(wxCommandEvent &event);
   void OnExport(wxCommandEvent &event);
   void OnCache(wxCommandEvent &event);
   void OnCacheDelete(wxCommandEvent &event);
