@@ -117,7 +117,6 @@ GOOrganController::GOOrganController(
     m_SampleSetId1(0),
     m_SampleSetId2(0),
     m_bitmaps(this),
-    m_GeneralTemplate(*this),
     m_PitchLabel(this),
     m_TemperamentLabel(this),
     m_MainWindowData(this, wxT("MainWindow")) {
@@ -133,8 +132,12 @@ GOOrganController::~GOOrganController() {
   m_manuals.clear();
   m_tremulants.clear();
   m_ranks.clear();
+  m_VirtualCouplers.Cleanup();
+  GOOrganModel::Cleanup();
   GOOrganModel::SetModelModificationListener(nullptr);
   GOOrganModel::SetMidiDialogCreator(nullptr);
+  GOOrganModel::SetCombinationController(nullptr);
+  m_elementcreators.clear();
 }
 
 void GOOrganController::SetOrganModified(bool modified) {
@@ -246,21 +249,14 @@ void GOOrganController::ReadOrganFile(GOConfigReader &cfg) {
   // It must be created before GOOrganModel::Load because lots of objects
   // reference to it
   m_setter = new GOSetter(this);
+  GOOrganModel::SetCombinationController(m_setter);
   m_elementcreators.push_back(m_setter);
 
-  GOOrganModel::Load(cfg, this);
+  GOOrganModel::Load(cfg);
 
-  for (unsigned i = 0; i < m_enclosures.size(); i++)
-    m_enclosures[i]->SetElementID(
-      GetRecorderElementID(wxString::Format(wxT("E%d"), i)));
+  m_VirtualCouplers.Init(*this, cfg);
 
-  for (unsigned i = 0; i < m_switches.size(); i++)
-    m_switches[i]->SetElementID(
-      GetRecorderElementID(wxString::Format(wxT("S%d"), i)));
-
-  for (unsigned i = 0; i < m_tremulants.size(); i++)
-    m_tremulants[i]->SetElementID(
-      GetRecorderElementID(wxString::Format(wxT("T%d"), i)));
+  GOOrganModel::LoadCmbButtons(cfg);
 
   m_DivisionalSetter = new GODivisionalSetter(this, m_setter->GetState());
   m_elementcreators.push_back(m_DivisionalSetter);
@@ -271,7 +267,7 @@ void GOOrganController::ReadOrganFile(GOConfigReader &cfg) {
   m_elementcreators.push_back(m_MidiPlayer);
   m_elementcreators.push_back(m_MidiRecorder);
   m_elementcreators.push_back(new GOMetronome(this));
-  m_panelcreators.push_back(new GOGUICouplerPanel(this));
+  m_panelcreators.push_back(new GOGUICouplerPanel(this, m_VirtualCouplers));
   m_panelcreators.push_back(new GOGUIFloatingPanel(this));
   m_panelcreators.push_back(new GOGUIMetronomePanel(this));
   m_panelcreators.push_back(new GOGUICrescendoPanel(this));
@@ -307,10 +303,6 @@ void GOOrganController::ReadOrganFile(GOConfigReader &cfg) {
   for (unsigned i = 0; i < m_panels.size(); i++)
     m_panels[i]->Layout();
 
-  m_GeneralTemplate.InitGeneral();
-  for (unsigned i = m_FirstManual; i < m_manuals.size(); i++)
-    m_manuals[i]->GetDivisionalTemplate().InitDivisional(i);
-
   GetRootPipeConfigNode().SetName(GetChurchName());
   ReadCombinations(cfg);
   m_setter->OnCombinationsLoaded(GetCombinationsDir(), wxEmptyString);
@@ -1085,14 +1077,6 @@ void GOOrganController::AllNotesOff() {
     GetManual(k)->AllNotesOff();
 }
 
-int GOOrganController::GetRecorderElementID(wxString name) {
-  return m_config.GetMidiMap().GetElementByString(name);
-}
-
-GOCombinationDefinition &GOOrganController::GetGeneralTemplate() {
-  return m_GeneralTemplate;
-}
-
 GOLabelControl *GOOrganController::GetPitchLabel() { return &m_PitchLabel; }
 
 GOLabelControl *GOOrganController::GetTemperamentLabel() {
