@@ -10,36 +10,28 @@
 #include "wx/intl.h"
 
 #include "combinations/GOSetter.h"
-#include "model/GOManual.h"
-
-#include "GOOrganController.h"
+#include "model/GOOrganModel.h"
 
 GODivisionalButtonControl::GODivisionalButtonControl(
-  GOOrganController *organController,
-  GOCombinationDefinition &divisionalTemplate,
-  bool isSetter)
-  : GOPushbuttonControl(*organController),
-    r_setter(*organController->GetSetter()),
-    m_combination(*organController, divisionalTemplate, isSetter) {}
+  GOOrganModel &organModel, unsigned manualNumber, bool isSetter)
+  : GOPushbuttonControl(organModel),
+    r_OrganModel(organModel),
+    m_combination(organModel, manualNumber, isSetter) {}
 
 wxString GODivisionalButtonControl::GetMidiType() { return _("Divisional"); };
 
 void GODivisionalButtonControl::Init(
   GOConfigReader &cfg,
   const wxString &group,
-  int manualNumber,
   int divisionalNumber,
   const wxString &name) {
   GOPushbuttonControl::Init(cfg, group, name);
-  m_combination.Init(group, manualNumber, divisionalNumber);
+  m_combination.Init(group, divisionalNumber);
 }
 void GODivisionalButtonControl::Load(
-  GOConfigReader &cfg,
-  const wxString &group,
-  int manualNumber,
-  int divisionalNumber) {
+  GOConfigReader &cfg, const wxString &group, int divisionalNumber) {
   GOPushbuttonControl::Load(cfg, group);
-  m_combination.Load(cfg, group, manualNumber, divisionalNumber);
+  m_combination.Load(cfg, group, divisionalNumber);
 }
 
 void GODivisionalButtonControl::LoadCombination(GOConfigReader &cfg) {
@@ -52,5 +44,5 @@ void GODivisionalButtonControl::Save(GOConfigWriter &cfg) {
 }
 
 void GODivisionalButtonControl::Push() {
-  r_setter.PushDivisional(m_combination, this);
+  r_OrganModel.PushDivisional(m_combination, this);
 }
