@@ -9,17 +9,14 @@
 
 #include <wx/intl.h>
 
-#include "combinations/GOSetter.h"
-
-#include "GOOrganController.h"
+#include "combinations/model/GOCombinationDefinition.h"
+#include "model/GOOrganModel.h"
 
 GOGeneralButtonControl::GOGeneralButtonControl(
-  GOCombinationDefinition &general_template,
-  GOOrganController *organController,
-  bool is_setter)
-  : GOPushbuttonControl(*organController),
-    r_setter(*organController->GetSetter()),
-    m_combination(*organController, general_template, is_setter) {}
+  GOOrganModel &organModel, bool is_setter)
+  : GOPushbuttonControl(organModel),
+    r_OrganModel(organModel),
+    m_combination(r_OrganModel, is_setter) {}
 
 void GOGeneralButtonControl::Load(GOConfigReader &cfg, wxString group) {
   m_combination.Load(cfg, group);
@@ -27,7 +24,7 @@ void GOGeneralButtonControl::Load(GOConfigReader &cfg, wxString group) {
 }
 
 void GOGeneralButtonControl::Push() {
-  r_setter.PushGeneral(m_combination, this);
+  r_OrganModel.PushGeneral(m_combination, this);
 }
 
 GOGeneralCombination &GOGeneralButtonControl::GetCombination() {
