@@ -12,18 +12,15 @@
 #include "control/GOPushbuttonControl.h"
 
 class GOConfigReader;
-class GOSetter;
+class GOOrganModel;
 
 class GOGeneralButtonControl : public GOPushbuttonControl {
 private:
-  GOSetter &r_setter;
+  GOOrganModel &r_OrganModel;
   GOGeneralCombination m_combination;
 
 public:
-  GOGeneralButtonControl(
-    GOCombinationDefinition &general_template,
-    GOOrganController *organController,
-    bool is_setter);
+  GOGeneralButtonControl(GOOrganModel &organModel, bool is_setter);
   void Load(GOConfigReader &cfg, wxString group);
   void Push() override;
   GOGeneralCombination &GetCombination();
