@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -164,6 +164,7 @@ GOConfig::GOConfig(wxString instance)
       sizeof(m_InitialLoadTypes) / sizeof(m_InitialLoadTypes[0]),
       GOInitialLoadType::LOAD_LAST_USED),
     ODFCheck(this, wxT("General"), wxT("StrictODFCheck"), false),
+    ODFHw1Check(this, wxT("General"), wxT("ODFHw1Check"), false),
     LoadChannels(this, wxT("General"), wxT("Channels"), 0, 2, 2),
     LosslessCompression(
       this, wxT("General"), wxT("LosslessCompression"), false),
@@ -206,6 +207,8 @@ GOConfig::GOConfig(wxString instance)
     OrganPath(this, wxT("General"), wxT("OrganPath"), wxEmptyString),
     OrganPackagePath(
       this, wxT("General"), wxT("OrganPackagePath"), wxEmptyString),
+    OrganCombinationsPath(
+      this, wxT("General"), wxT("CmbYamlPath"), wxEmptyString),
     ExportImportPath(this, wxT("General"), wxT("CMBPath"), wxEmptyString),
     AudioRecorderPath(
       this, wxT("General"), wxT("AudioRecorder"), wxEmptyString),
@@ -227,6 +230,8 @@ GOConfig::GOConfig(wxString instance)
     GOStdPath::GetGrandOrgueSubDir(wxT("Cache") + m_InstanceName));
   OrganSettingsPath.setDefaultValue(
     GOStdPath::GetGrandOrgueSubDir(wxT("Data") + m_InstanceName));
+  OrganCombinationsPath.setDefaultValue(
+    GOStdPath::GetGrandOrgueSubDir(_("Combinations")));
   ExportImportPath.setDefaultValue(
     GOStdPath::GetGrandOrgueSubDir(_("Settings")));
   AudioRecorderPath.setDefaultValue(
@@ -395,6 +400,10 @@ void GOConfig::Load() {
 
       GOSettingStore::Load(cfg);
 
+    // Fill ODFHw1Check with ODFCheck by default
+    if (!ODFHw1Check.IsPresent())
+      ODFHw1Check(ODFCheck());
+
     if (Concurrency() == 0)
       Concurrency(1);
 
@@ -448,7 +457,7 @@ void GOConfig::SetLanguageId(int langId) {
                                  : wxLocale::GetLanguageCanonicalName(langId));
 }
 
-unsigned GOConfig::GetEventCount() {
+unsigned GOConfig::GetEventCount() const {
   return sizeof(m_MIDISettings) / sizeof(m_MIDISettings[0]);
 }
 
@@ -480,13 +489,13 @@ wxString GOConfig::GetEventTitle(unsigned index) {
   return wxGetTranslation(m_MIDISettings[index].name);
 }
 
-GOMidiReceiverBase *GOConfig::GetMidiEvent(unsigned index) {
+const GOMidiReceiverBase *GOConfig::GetMidiEvent(unsigned index) const {
   assert(index < GetEventCount());
   return m_MIDIEvents[index];
 }
 
-GOMidiReceiverBase *GOConfig::FindMidiEvent(
-  GOMidiReceiverType type, unsigned index) {
+const GOMidiReceiverBase *GOConfig::FindMidiEvent(
+  GOMidiReceiverType type, unsigned index) const {
   for (unsigned i = 0; i < GetEventCount(); i++)
     if (m_MIDISettings[i].type == type && m_MIDISettings[i].index == index)
       return m_MIDIEvents[i];
