@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -98,6 +98,7 @@ public:
   GOSettingBool CompressCache;
   GOSettingEnum<GOInitialLoadType> LoadLastFile;
   GOSettingBool ODFCheck;
+  GOSettingBool ODFHw1Check;
 
   GOSettingUnsigned LoadChannels;
   GOSettingBool LosslessCompression;
@@ -140,6 +141,7 @@ public:
         store, group, name, min_value, max_value, default_value) {}
 
   } BitsPerSample;
+
   GOSettingInteger Transpose;
 
   GOSettingUnsigned MetronomeMeasure;
@@ -151,6 +153,7 @@ public:
 
   GOSettingDirectory OrganPath;
   GOSettingDirectory OrganPackagePath;
+  GOSettingDirectory OrganCombinationsPath;
   GOSettingDirectory ExportImportPath;
   GOSettingDirectory AudioRecorderPath;
   GOSettingDirectory MidiRecorderPath;
@@ -167,25 +170,12 @@ public:
   const wxString &GetResourceDirectory() const { return m_ResourceDir; }
   const wxString GetPackageDirectory();
 
-  unsigned GetEventCount();
+  unsigned GetEventCount() const;
   wxString GetEventGroup(unsigned index);
   wxString GetEventTitle(unsigned index);
-  GOMidiReceiverBase *GetMidiEvent(unsigned index);
-  GOMidiReceiverBase *FindMidiEvent(GOMidiReceiverType type, unsigned index);
-
-  /*
-  bool GetMidiInState(wxString device, bool isEnabledByDefault);
-  void SetMidiInState(wxString device, bool enabled);
-  unsigned GetMidiInDeviceChannelShift(wxString device);
-  void SetMidiInDeviceChannelShift(wxString device, unsigned shift);
-  wxString GetMidiInOutDevice(wxString device);
-  void SetMidiInOutDevice(wxString device, wxString out_device);
-  std::vector<wxString> GetMidiInDeviceList();
-
-  bool GetMidiOutState(wxString device);
-  void SetMidiOutState(wxString device, bool enabled);
-  std::vector<wxString> GetMidiOutDeviceList();
-   */
+  const GOMidiReceiverBase *GetMidiEvent(unsigned index) const;
+  const GOMidiReceiverBase *FindMidiEvent(
+    GOMidiReceiverType type, unsigned index) const;
 
   const std::vector<wxString> &GetAudioGroups();
   void SetAudioGroups(const std::vector<wxString> &audio_groups);
