@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -12,16 +12,16 @@
 #include "control/GOButtonCallback.h"
 
 GOCallbackButtonControl::GOCallbackButtonControl(
-  GOOrganController *organController,
+  GOOrganModel &organModel,
   GOButtonCallback *callback,
   bool isPushbutton,
   bool isPiston)
-  : GOButtonControl(organController, MIDI_RECV_SETTER, isPushbutton, isPiston),
+  : GOButtonControl(organModel, MIDI_RECV_SETTER, isPushbutton, isPiston),
     m_callback(callback) {}
 
 void GOCallbackButtonControl::Push() {
   if (m_Pushbutton)
-    m_callback->ButtonStateChanged(this);
+    m_callback->ButtonStateChanged(this, true);
   else
     GOButtonControl::Push();
 }
@@ -29,7 +29,7 @@ void GOCallbackButtonControl::Push() {
 void GOCallbackButtonControl::Set(bool on) {
   if (IsEngaged() == on)
     return;
-  m_callback->ButtonStateChanged(this);
+  m_callback->ButtonStateChanged(this, on);
   Display(on);
 }
 
