@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -18,7 +18,7 @@ protected:
 
 public:
   GOCallbackButtonControl(
-    GOOrganController *organController,
+    GOOrganModel &organModel,
     GOButtonCallback *callback,
     bool isPushbutton,
     bool isPiston = false);
