@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -10,17 +10,18 @@
 
 #include <wx/string.h>
 
-#include "GOPlaybackStateHandler.h"
-#include "GOSaveableObject.h"
 #include "midi/GOMidiConfigurator.h"
 #include "midi/GOMidiSender.h"
+#include "sound/GOSoundStateHandler.h"
+
+#include "GOSaveableObject.h"
 
 class GOConfigReader;
 class GOConfigWriter;
 class GOOrganController;
 
 class GOLabelControl : private GOSaveableObject,
-                       private GOPlaybackStateHandler,
+                       private GOSoundStateHandler,
                        public GOMidiConfigurator {
 protected:
   wxString m_Name;
@@ -33,7 +34,6 @@ protected:
 
   void AbortPlayback();
   void PreparePlayback();
-  void StartPlayback();
   void PrepareRecording();
 
 public:
