@@ -12,22 +12,17 @@
 
 #include <wx/propdlg.h>
 
-#include "GODialogCloser.h"
+#include "GODialog.h"
 
 class wxBookCtrlBase;
 class wxPanel;
-class wxSizer;
 
 class GODialogTab;
 
-class GOTabbedDialog : public wxPropertySheetDialog, public GODialogCloser {
+class GOTabbedDialog : public GODialog<wxPropertySheetDialog> {
 private:
-  const wxString m_name;
   std::vector<wxString> m_TabNames;
   wxBookCtrlBase *p_book;
-  wxSizer *p_ButtonSizer;
-
-  void OnHelp(wxCommandEvent &event);
 
 protected:
   GOTabbedDialog(
@@ -36,23 +31,20 @@ protected:
     const wxString &title, // translated
     long addStyle = 0);
 
-  wxSizer *GetButtonSizer() const { return p_ButtonSizer; }
-
   void AddTab(wxPanel *tab, const wxString &tabName, const wxString &tabTitle);
   void AddTab(GODialogTab *tab);
 
 public:
   const wxString &GetCurrTabName() const;
-
   wxBookCtrlBase *GetBook() const { return p_book; }
 
+  const wxString &GetHelpSuffix() const override { return GetCurrTabName(); }
+
   void NavigateToTab(const wxString &tabName);
 
   virtual bool TransferDataToWindow() override;
   virtual bool Validate() override;
   virtual bool TransferDataFromWindow() override;
-
-  DECLARE_EVENT_TABLE()
 };
 
 #endif /* GOTABBEDDIALOG_H */
