@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -320,7 +320,8 @@ bool GOMidiEventRecvTab::TransferDataFromWindow() {
       }
   } while (empty_event);
 
-  m_original->Assign(m_midi);
+  if (m_original->RenewFrom(m_midi))
+    GOModificationProxy::OnIsModifiedChanged(true);
   return true;
 }
 
