@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -16,6 +16,7 @@
 #include "midi/GOMidiCallback.h"
 #include "midi/GOMidiListener.h"
 #include "midi/GOMidiReceiverBase.h"
+#include "modification/GOModificationProxy.h"
 
 #include "GOChoice.h"
 
@@ -28,7 +29,9 @@ class wxToggleButton;
 class GOConfig;
 class GOMidiDeviceConfigList;
 
-class GOMidiEventRecvTab : public wxPanel, protected GOMidiCallback {
+class GOMidiEventRecvTab : public wxPanel,
+                           public GOModificationProxy,
+                           protected GOMidiCallback {
 private:
   GOMidiDeviceConfigList &m_MidiIn;
   GOMidiMap &m_MidiMap;
