@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -274,7 +274,8 @@ bool GOMidiEventSendTab::TransferDataFromWindow() {
   } while (empty_event);
   // The event with index 0 is also deleted so the dialog can't be used more
 
-  m_original->Assign(m_midi);
+  if (m_original->RenewFrom(m_midi))
+    OnIsModifiedChanged(true);
   return true;
 }
 
