@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -11,10 +11,12 @@
 #include <wx/gdicmn.h>
 #include <wx/string.h>
 
-#include "GOBitmap.h"
-#include "GOSaveableObject.h"
 #include "ptrvector.h"
 
+#include "primitives/GOBitmap.h"
+
+#include "GOSaveableObject.h"
+
 class GOGUIControl;
 class GOGUIDisplayMetrics;
 class GOGUILayoutEngine;
@@ -32,6 +34,19 @@ class GOOrganController;
 class GOGUIPanel : private GOSaveableObject {
 private:
   void ReadSizeInfoFromCfg(GOConfigReader &cfg, bool isOpenByDefault);
+  void LoadButton(
+    GOConfigReader &cfg,
+    GOButtonControl *pButtonControl,
+    const wxString &groupPrefix,
+    unsigned groupIndex,
+    bool isPiston = false);
+  void LoadManualButton(
+    GOConfigReader &cfg,
+    GOButtonControl *pButtonControl,
+    const wxString &manualGroup,
+    const wxString &groupPrefix,
+    unsigned elementIndex,
+    bool isPiston = false);
 
 protected:
   GOOrganController *m_OrganController;
