@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -10,8 +10,9 @@
 #include <wx/dcclient.h>
 #include <wx/dcmemory.h>
 
-#include "GODC.h"
-#include "GOFont.h"
+#include "primitives/GODC.h"
+#include "primitives/GOFont.h"
+
 #include "GOGUIControl.h"
 #include "GOGUIPanel.h"
 #include "GOKeyConvert.h"
