@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -47,7 +47,7 @@ GOMidiPlayer::GOMidiPlayer(GOOrganController *organController)
     m_Speed(1),
     m_IsPlaying(false),
     m_Pause(false) {
-  CreateButtons(m_OrganController);
+  CreateButtons(*m_OrganController);
   Clear();
   m_DeviceID
     = m_OrganController->GetSettings().GetMidiMap().GetDeviceIdByLogicalName(
@@ -65,7 +65,7 @@ void GOMidiPlayer::Load(GOConfigReader &cfg) {
   m_PlayingTime.Init(cfg, wxT("MidiPlayerTime"), _("MIDI playing time"));
 }
 
-void GOMidiPlayer::ButtonStateChanged(int id) {
+void GOMidiPlayer::ButtonStateChanged(int id, bool newState) {
   switch (id) {
   case ID_MIDI_PLAYER_STOP:
     StopPlaying();
