@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -62,7 +62,7 @@ GOMidiRecorder::GOMidiRecorder(GOOrganController *organController)
     m_BufferPos(0),
     m_FileLength(0),
     m_Last(0) {
-  CreateButtons(m_OrganController);
+  CreateButtons(*m_OrganController);
   Clear();
   UpdateDisplay();
 }
@@ -79,7 +79,7 @@ void GOMidiRecorder::Load(GOConfigReader &cfg) {
   m_RecordingTime.Init(cfg, wxT("MidiRecordTime"), _("MIDI recording time"));
 }
 
-void GOMidiRecorder::ButtonStateChanged(int id) {
+void GOMidiRecorder::ButtonStateChanged(int id, bool newState) {
   switch (id) {
   case ID_MIDI_RECORDER_STOP:
     StopRecording();
