@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -9,17 +9,15 @@
 
 #include <wx/intl.h>
 
-#include "GOOrganController.h"
 #include "config/GOConfigReader.h"
 #include "config/GOConfigWriter.h"
 #include "midi/GOMidiEvent.h"
 #include "midi/GOMidiMap.h"
 
-GOMidiSender::GOMidiSender(
-  GOOrganController *organController, GOMidiSenderType type)
-  : GOMidiSenderEventPatternList(type),
-    m_OrganController(organController),
-    m_ElementID(-1) {}
+#include "GOMidiSendProxy.h"
+
+GOMidiSender::GOMidiSender(GOMidiSendProxy &proxy, GOMidiSenderType type)
+  : GOMidiSenderEventPatternList(type), r_proxy(proxy), m_ElementID(-1) {}
 
 GOMidiSender::~GOMidiSender() {}
 
@@ -309,7 +307,7 @@ void GOMidiSender::SetDisplay(bool state) {
     e.SetMidiType(MIDI_NRPN);
     e.SetDevice(m_ElementID);
     e.SetValue(state ? 0x7F : 0x00);
-    m_OrganController->SendMidiRecorderMessage(e);
+    r_proxy.SendMidiRecorderMessage(e);
   }
 
   for (unsigned i = 0; i < m_events.size(); i++) {
@@ -320,7 +318,7 @@ void GOMidiSender::SetDisplay(bool state) {
       e.SetChannel(m_events[i].channel);
       e.SetKey(m_events[i].key);
       e.SetValue(state ? m_events[i].high_value : m_events[i].low_value);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_CTRL) {
       GOMidiEvent e;
@@ -329,7 +327,7 @@ void GOMidiSender::SetDisplay(bool state) {
       e.SetChannel(m_events[i].channel);
       e.SetKey(m_events[i].key);
       e.SetValue(state ? m_events[i].high_value : m_events[i].low_value);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_RPN) {
       GOMidiEvent e;
@@ -338,7 +336,7 @@ void GOMidiSender::SetDisplay(bool state) {
       e.SetChannel(m_events[i].channel);
       e.SetKey(m_events[i].key);
       e.SetValue(state ? m_events[i].high_value : m_events[i].low_value);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_NRPN) {
       GOMidiEvent e;
@@ -347,7 +345,7 @@ void GOMidiSender::SetDisplay(bool state) {
       e.SetChannel(m_events[i].channel);
       e.SetKey(m_events[i].key);
       e.SetValue(state ? m_events[i].high_value : m_events[i].low_value);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_PGM_RANGE) {
       GOMidiEvent e;
@@ -355,7 +353,7 @@ void GOMidiSender::SetDisplay(bool state) {
       e.SetMidiType(MIDI_PGM_CHANGE);
       e.SetChannel(m_events[i].channel);
       e.SetKey(state ? m_events[i].high_value : m_events[i].low_value);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_RPN_RANGE) {
       GOMidiEvent e;
@@ -364,7 +362,7 @@ void GOMidiSender::SetDisplay(bool state) {
       e.SetChannel(m_events[i].channel);
       e.SetValue(m_events[i].key);
       e.SetKey(state ? m_events[i].high_value : m_events[i].low_value);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_NRPN_RANGE) {
       GOMidiEvent e;
@@ -373,7 +371,7 @@ void GOMidiSender::SetDisplay(bool state) {
       e.SetChannel(m_events[i].channel);
       e.SetValue(m_events[i].key);
       e.SetKey(state ? m_events[i].high_value : m_events[i].low_value);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_PGM_ON && state) {
       GOMidiEvent e;
@@ -381,7 +379,7 @@ void GOMidiSender::SetDisplay(bool state) {
       e.SetMidiType(MIDI_PGM_CHANGE);
       e.SetChannel(m_events[i].channel);
       e.SetKey(m_events[i].key);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_PGM_OFF && !state) {
       GOMidiEvent e;
@@ -389,7 +387,7 @@ void GOMidiSender::SetDisplay(bool state) {
       e.SetMidiType(MIDI_PGM_CHANGE);
       e.SetChannel(m_events[i].channel);
       e.SetKey(m_events[i].key);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_NOTE_ON && state) {
       GOMidiEvent e;
@@ -398,7 +396,7 @@ void GOMidiSender::SetDisplay(bool state) {
       e.SetChannel(m_events[i].channel);
       e.SetKey(m_events[i].key);
       e.SetValue(m_events[i].high_value);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_NOTE_OFF && !state) {
       GOMidiEvent e;
@@ -407,7 +405,7 @@ void GOMidiSender::SetDisplay(bool state) {
       e.SetChannel(m_events[i].channel);
       e.SetKey(m_events[i].key);
       e.SetValue(m_events[i].low_value);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_CTRL_ON && state) {
       GOMidiEvent e;
@@ -416,7 +414,7 @@ void GOMidiSender::SetDisplay(bool state) {
       e.SetChannel(m_events[i].channel);
       e.SetKey(m_events[i].key);
       e.SetValue(m_events[i].high_value);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_CTRL_OFF && !state) {
       GOMidiEvent e;
@@ -425,7 +423,7 @@ void GOMidiSender::SetDisplay(bool state) {
       e.SetChannel(m_events[i].channel);
       e.SetKey(m_events[i].key);
       e.SetValue(m_events[i].low_value);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_RPN_ON && state) {
       GOMidiEvent e;
@@ -434,7 +432,7 @@ void GOMidiSender::SetDisplay(bool state) {
       e.SetChannel(m_events[i].channel);
       e.SetKey(m_events[i].key);
       e.SetValue(m_events[i].high_value);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_RPN_OFF && !state) {
       GOMidiEvent e;
@@ -443,7 +441,7 @@ void GOMidiSender::SetDisplay(bool state) {
       e.SetChannel(m_events[i].channel);
       e.SetKey(m_events[i].key);
       e.SetValue(m_events[i].low_value);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_NRPN_ON && state) {
       GOMidiEvent e;
@@ -452,7 +450,7 @@ void GOMidiSender::SetDisplay(bool state) {
       e.SetChannel(m_events[i].channel);
       e.SetKey(m_events[i].key);
       e.SetValue(m_events[i].high_value);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_NRPN_OFF && !state) {
       GOMidiEvent e;
@@ -461,7 +459,7 @@ void GOMidiSender::SetDisplay(bool state) {
       e.SetChannel(m_events[i].channel);
       e.SetKey(m_events[i].key);
       e.SetValue(m_events[i].low_value);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_HW_LCD) {
       GOMidiEvent e;
@@ -471,7 +469,7 @@ void GOMidiSender::SetDisplay(bool state) {
       e.SetKey(m_events[i].key);
       e.SetValue(m_events[i].start);
       e.SetString(state ? _("ON") : _("OFF"), m_events[i].length);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_HW_STRING) {
       GOMidiEvent e;
@@ -480,7 +478,7 @@ void GOMidiSender::SetDisplay(bool state) {
       e.SetKey(m_events[i].key);
       e.SetValue(m_events[i].start);
       e.SetString(state ? _("ON") : _("OFF"), m_events[i].length);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_RODGERS_STOP_CHANGE) {
       GOMidiEvent e;
@@ -489,7 +487,7 @@ void GOMidiSender::SetDisplay(bool state) {
       e.SetChannel(m_events[i].key);
       e.SetKey(m_events[i].low_value);
       e.SetValue(state);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
   }
 }
@@ -501,7 +499,7 @@ void GOMidiSender::ResetKey() {
     e.SetDevice(m_ElementID);
     e.SetKey(MIDI_CTRL_NOTES_OFF);
     e.SetValue(0);
-    m_OrganController->SendMidiRecorderMessage(e);
+    r_proxy.SendMidiRecorderMessage(e);
   }
 
   for (unsigned i = 0; i < m_events.size(); i++) {
@@ -514,7 +512,7 @@ void GOMidiSender::ResetKey() {
       e.SetChannel(m_events[i].channel);
       e.SetKey(MIDI_CTRL_NOTES_OFF);
       e.SetValue(0);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
   }
 }
@@ -526,7 +524,7 @@ void GOMidiSender::SetKey(unsigned key, unsigned velocity) {
     e.SetDevice(m_ElementID);
     e.SetKey(key & 0x7F);
     e.SetValue(velocity & 0x7F);
-    m_OrganController->SendMidiRecorderMessage(e);
+    r_proxy.SendMidiRecorderMessage(e);
   }
 
   for (unsigned i = 0; i < m_events.size(); i++) {
@@ -537,7 +535,7 @@ void GOMidiSender::SetKey(unsigned key, unsigned velocity) {
       e.SetChannel(m_events[i].channel);
       e.SetKey(key);
       e.SetValue(m_events[i].ConvertIntValueToDst(velocity));
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_NOTE_NO_VELOCITY) {
       GOMidiEvent e;
@@ -546,7 +544,7 @@ void GOMidiSender::SetKey(unsigned key, unsigned velocity) {
       e.SetChannel(m_events[i].channel);
       e.SetKey(key);
       e.SetValue(velocity ? m_events[i].high_value : m_events[i].low_value);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
   }
 }
@@ -557,7 +555,7 @@ void GOMidiSender::SetValue(unsigned value) {
     e.SetMidiType(MIDI_NRPN);
     e.SetDevice(m_ElementID);
     e.SetValue(value & 0x7F);
-    m_OrganController->SendMidiRecorderMessage(e);
+    r_proxy.SendMidiRecorderMessage(e);
   }
 
   for (unsigned i = 0; i < m_events.size(); i++) {
@@ -568,7 +566,7 @@ void GOMidiSender::SetValue(unsigned value) {
       e.SetChannel(m_events[i].channel);
       e.SetKey(m_events[i].key);
       e.SetValue(m_events[i].ConvertIntValueToDst(value));
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_RPN) {
       GOMidiEvent e;
@@ -577,7 +575,7 @@ void GOMidiSender::SetValue(unsigned value) {
       e.SetChannel(m_events[i].channel);
       e.SetKey(m_events[i].key);
       e.SetValue(m_events[i].ConvertIntValueToDst(value));
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_NRPN) {
       GOMidiEvent e;
@@ -586,7 +584,7 @@ void GOMidiSender::SetValue(unsigned value) {
       e.SetChannel(m_events[i].channel);
       e.SetKey(m_events[i].key);
       e.SetValue(m_events[i].ConvertIntValueToDst(value));
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_PGM_RANGE) {
       GOMidiEvent e;
@@ -594,7 +592,7 @@ void GOMidiSender::SetValue(unsigned value) {
       e.SetMidiType(MIDI_PGM_CHANGE);
       e.SetChannel(m_events[i].channel);
       e.SetKey(m_events[i].ConvertIntValueToDst(value));
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_HW_LCD) {
       GOMidiEvent e;
@@ -605,7 +603,7 @@ void GOMidiSender::SetValue(unsigned value) {
       e.SetValue(m_events[i].start);
       e.SetString(
         wxString::Format(_("%d %%"), value * 100 / 127), m_events[i].length);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_HW_STRING) {
       GOMidiEvent e;
@@ -615,7 +613,7 @@ void GOMidiSender::SetValue(unsigned value) {
       e.SetValue(m_events[i].start);
       e.SetString(
         wxString::Format(_("%d %%"), value * 100 / 127), m_events[i].length);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
   }
 }
@@ -630,7 +628,7 @@ void GOMidiSender::SetLabel(const wxString &text) {
       e.SetKey(m_events[i].key);
       e.SetValue(m_events[i].start);
       e.SetString(text, m_events[i].length);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_HW_STRING) {
       GOMidiEvent e;
@@ -639,7 +637,7 @@ void GOMidiSender::SetLabel(const wxString &text) {
       e.SetKey(m_events[i].key);
       e.SetValue(m_events[i].start);
       e.SetString(text, m_events[i].length);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
   }
 }
@@ -654,7 +652,7 @@ void GOMidiSender::SetName(const wxString &text) {
       e.SetKey(m_events[i].key);
       e.SetValue(m_events[i].start);
       e.SetString(text, m_events[i].length);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
     if (m_events[i].type == MIDI_S_HW_NAME_STRING) {
       GOMidiEvent e;
@@ -663,13 +661,7 @@ void GOMidiSender::SetName(const wxString &text) {
       e.SetKey(m_events[i].key);
       e.SetValue(m_events[i].start);
       e.SetString(text, m_events[i].length);
-      m_OrganController->SendMidiMessage(e);
+      r_proxy.SendMidiMessage(e);
     }
   }
 }
-
-void GOMidiSender::Assign(const GOMidiSenderEventPatternList &data) {
-  *(GOMidiSenderEventPatternList *)this = data;
-  if (m_OrganController)
-    m_OrganController->SetOrganModified();
-}
