@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -15,17 +15,17 @@
 class GOConfigReader;
 class GOConfigWriter;
 class GOMidiMap;
-class GOOrganController;
+class GOMidiSendProxy;
 struct IniFileEnumEntry;
 
 class GOMidiSender : public GOMidiSenderEventPatternList {
 private:
   static const struct IniFileEnumEntry m_MidiTypes[];
-  GOOrganController *m_OrganController;
+  GOMidiSendProxy &r_proxy;
   int m_ElementID;
 
 public:
-  GOMidiSender(GOOrganController *organController, GOMidiSenderType type);
+  GOMidiSender(GOMidiSendProxy &proxy, GOMidiSenderType type);
   ~GOMidiSender();
 
   void SetElementID(int id);
@@ -51,8 +51,6 @@ public:
   unsigned HighValueLimit(GOMidiSenderMessageType type);
   unsigned StartLimit(GOMidiSenderMessageType type);
   unsigned LengthLimit(GOMidiSenderMessageType type);
-
-  void Assign(const GOMidiSenderEventPatternList &data);
 };
 
 #endif
