@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -33,14 +33,13 @@ private:
 
   void SetRankKey(unsigned key, unsigned velocity);
   void ChangeState(bool on);
-  void SetupCombinationState();
 
   void AbortPlayback();
   void PreparePlayback();
   void StartPlayback();
 
 public:
-  GOStop(GOOrganController *organController, unsigned first_midi_note_number);
+  GOStop(GOOrganModel &organModel, unsigned first_midi_note_number);
   GORank *GetRank(unsigned index);
   void Load(GOConfigReader &cfg, wxString group);
   void SetKey(unsigned note, unsigned velocity);
