@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -13,10 +13,9 @@
 class GOSwitch : public GODrawstop {
 protected:
   void ChangeState(bool);
-  void SetupCombinationState();
 
 public:
-  GOSwitch(GOOrganController *organController);
+  GOSwitch(GOOrganModel &organModel);
   ~GOSwitch();
 
   wxString GetMidiType();
